@@ -18,17 +18,42 @@ __correspondence_email__ = 'alexander.juestel@rwth-aachen.de'
 
 __affiliations__ = 'CGRE - RWTH Aachen University'
 
-__version_date__ = '2021-03-30'
+__version_date__ = '2021-04-07'
 
-__version__ = '0.1.13'
+__version__ = '0.1.18'
 
-__changelog__ = """What is new in version 0.1.13:
-- Adding Example
-- Adding Three Point Problem Function
+__changelog__ = """What is new in version 0.1.18:
+- Adding Edits to publish on conda-forge
 
 """
 
-__changelogs__ = {'0.1.12': """What is new in version 0.1.12:
+__changelogs__ = {'0.1.17': """What is new in version 0.1.17:
+- Adding Edits to publish on conda-forge
+
+""",
+
+                 '0.1.16': """What is new in version 0.1.16:
+- Adding Edits to publish on conda-forge
+
+""",
+
+                 '0.1.15': """What is new in version 0.1.15:
+- Adding Examples
+- Adding Github Action for automatic PyPi release 
+
+""",
+
+
+                 '0.1.14': """What is new in version 0.1.14:
+- Adding Examples
+""",
+
+                 '0.1.13': """What is new in version 0.1.13:
+- Adding Example
+- Adding Three Point Problem Function
+""",
+
+                  '0.1.12': """What is new in version 0.1.12:
 - Removing more dependencies
 - Minor bug fixes
 """,
